@@ -113,11 +113,11 @@ class ShelfModelView(sqla.ModelView):
 
         for k, v in self.model.__dict__.items():
             if hasattr(v, "mapper"):
-                if issubclass(v.mapper.class_, shelf_computed_models()['LocalizedString']):
+                if 'LocalizedString' in shelf_computed_models() and issubclass(v.mapper.class_, shelf_computed_models()['LocalizedString']):
                    columns[k] = v
-                if issubclass(v.mapper.class_, shelf_computed_models()['Picture']):
+                if 'Picture' in shelf_computed_models() and issubclass(v.mapper.class_, shelf_computed_models()['Picture']):
                    columns[k] = v
-                if issubclass(v.mapper.class_, shelf_computed_models()['RemoteFile']):
+                if 'RemoteFile' in shelf_computed_models() and issubclass(v.mapper.class_, shelf_computed_models()['RemoteFile']):
                    columns[k] = v
 
         return columns
